@@ -4,8 +4,11 @@ import io
 import json
 import logging
 import pickle
+import sys
+import time
 import zlib
 
+
 import socketio
 import ubjson
 import ujson as ujson
@@ -34,12 +37,10 @@ class GSCNodeFunctionReceiverSocket:
 
         @self.sio.event
         def oncnodefunction(id, msg):
-            decompressed_byte_data = zlib.decompress(msg)
-            msg1 = ubjson.loadb(decompressed_byte_data)
-            if msg1["cnodefunction"] == self.gsdbs.credentials["cnode"]:
-                self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, msg1],
-                                       callback=on_success,
-                                       error_callback=on_errorPost)
+            msg1 = ubjson.loadb(msg)
+            self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, msg1],
+                                   callback=on_success,
+                                   error_callback=on_errorPost)
 
         connectURL = ""
 
@@ -103,7 +104,7 @@ class GSCNodeFunctionCaller:
         self.sio = socketio.Client()
         self.gsdbs = gsdbs
         self.oncnodefunctionanswer = oncnodefunctionanswer
-        self._pool = Pool(100)
+        self._pool = Pool(self.gsdbs.credentials["poolsize"])
         self._logger = logging.getLogger(__name__)
 
     def startSocket(self):
@@ -116,13 +117,13 @@ class GSCNodeFunctionCaller:
         self._logger.exception('cnodefunction failed :' + error)
 
     def emitFunction(self, sio, target, msg):
-        # sio.emit("oncnodefunction", {"target": target, "message": ujson.dumps(msg)})
         msg["cnodefunction"] = target
 
-        encoded=ubjson.dumpb(msg)
-        compressed_data =zlib.compress(encoded)
-        sio.emit("oncnodefunction", compressed_data)
+        encoded = ubjson.dumpb(msg)
+
+        sio.emit("oncnodefunction", {"target": target, "data": encoded})
 
     def sendcnodefunction(self, target, msg):
+        time.sleep(0.01)
         self._pool.apply_async(self.emitFunction, args=[self.sio, target, msg], callback=self.on_success,
                                error_callback=self.on_errorPost)
