@@ -106,7 +106,8 @@ class FrameBufferThread(Thread):
     def __init__(self, gsdbs, target, onframe):
         super(FrameBufferThread, self).__init__()
         self.gsdbs = gsdbs
-        self.gsdbs.logger.debug("Starting Buffer")
+        self.logger = logging.getLogger(__name__)
+        self.logger.debug("Starting Buffer")
         self.target = target
         self.onframe = onframe
         self.nal_queue = Queue(3)
